==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-calculator/i18n/l-calc_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>mainUI</name>
    <message>
        <location filename="../mainUI.ui" line="14"/>
        <location filename="../mainUI.cpp" line="53"/>
        <source>Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="657"/>
        <source>Advanced Operations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="77"/>
        <source>Percentage %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="79"/>
        <source>Power %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="81"/>
        <source>Base-10 Exponential %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="83"/>
        <source>Exponential %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="85"/>
        <source>Constant Pi %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="88"/>
        <source>Square Root %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="90"/>
        <source>Logarithm %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="92"/>
        <source>Natural Log %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="95"/>
        <source>Sine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="97"/>
        <source>Cosine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="99"/>
        <source>Tangent %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="102"/>
        <source>Arc Sine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="104"/>
        <source>Arc Cosine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="106"/>
        <source>Arc Tangent %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="109"/>
        <source>Hyperbolic Sine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="111"/>
        <source>Hyperbolic Cosine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="113"/>
        <source>Hyperbolic Tangent %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="176"/>
        <source>Save Calculator History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/desktop-utils/lumina-calculator/i18n/l-calc_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mainUI</name>
    <message>
        <location filename="../mainUI.ui" line="14"/>
        <location filename="../mainUI.cpp" line="53"/>
        <source>Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="657"/>
        <source>Advanced Operations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="83"/>
        <source>Percentage %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="85"/>
        <source>Power %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="87"/>
        <source>Base-10 Exponential %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="89"/>
        <source>Exponential %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="91"/>
        <source>Constant Pi %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="94"/>
        <source>Square Root %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="96"/>
        <source>Logarithm %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="98"/>
        <source>Natural Log %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="101"/>
        <source>Sine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="103"/>
        <source>Cosine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="105"/>
        <source>Tangent %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="108"/>
        <source>Arc Sine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="110"/>
        <source>Arc Cosine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="112"/>
        <source>Arc Tangent %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="115"/>
        <source>Hyperbolic Sine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="117"/>
        <source>Hyperbolic Cosine %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="119"/>
        <source>Hyperbolic Tangent %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="182"/>
        <source>Save Calculator History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
